@@ -166,9 +166,9 @@ plotlmforecast <- function(object, plot.conf, shaded, shadecols, col, fcol, pi.c
     {
       #require(colorspace)
       if(min(object$level) < 50) # Using very small confidence levels.
-        shadecols <- rev(colorspace:::sequential_hcl(100)[object$level])
+        shadecols <- rev(colorspace::sequential_hcl(100)[object$level])
       else # This should happen almost all the time. Colors mapped to levels.
-        shadecols <- rev(colorspace:::sequential_hcl(52)[object$level-49])
+        shadecols <- rev(colorspace::sequential_hcl(52)[object$level-49])
     }
     if(length(shadecols)==1)
     {
@@ -275,9 +275,9 @@ plot.forecast <- function(x, include, plot.conf=TRUE, shaded=TRUE, shadebars=(le
     {
       #require(colorspace)
       if(min(x$level) < 50) # Using very small confidence levels.
-        shadecols <- rev(colorspace:::sequential_hcl(100)[x$level])
+        shadecols <- rev(colorspace::sequential_hcl(100)[x$level])
       else # This should happen almost all the time. Colors mapped to levels.
-        shadecols <- rev(colorspace:::sequential_hcl(52)[x$level-49])
+        shadecols <- rev(colorspace::sequential_hcl(52)[x$level-49])
     }
     if(length(shadecols)==1)
     {
@@ -325,3 +325,12 @@ predict.default <- function(object, ...)
 {
     forecast(object, ...)
 }
+
+# The following function is for when users don't realise they already have the forecasts. 
+# e.g., with the dshw(), meanf() or rwf() functions.
+
+forecast.forecast <- function(object, ...)
+{
+  return(object)
+}
+
